Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InitRestApi ¶
func InitRestApi(port string)
InitRestApi initializes the router and starts listening on `port`.
func InitRouter ¶
InitRouter initializes the router with required middleware and routes.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.